@@ -53,7 +53,7 @@ GST_START_TEST (test_layer_properties)
   fail_unless (clip != NULL);
 
   /* Set some properties */
-  g_object_set (clip, "start", (guint64) 42, "duration", (guint64) 51,
+  g_object_set (clip, "start", (guint64) 42, "duration", (gint64) 51,
       "in-point", (guint64) 12, NULL);
   assert_equals_uint64 (_START (clip), 42);
   assert_equals_uint64 (_DURATION (clip), 51);
@@ -144,9 +144,9 @@ GST_START_TEST (test_layer_priorities)
   fail_unless (clip2 != NULL);
   fail_unless (clip3 != NULL);
 
-  g_object_set (clip1, "start", 0, "duration", 10, NULL);
-  g_object_set (clip2, "start", 10, "duration", 10, NULL);
-  g_object_set (clip3, "start", 20, "duration", 10, NULL);
+  g_object_set (clip1, "start", (guint64) 0, "duration", (gint64) 10, NULL);
+  g_object_set (clip2, "start", (guint64) 10, "duration", (gint64) 10, NULL);
+  g_object_set (clip3, "start", (guint64) 20, "duration", (gint64) 10, NULL);
 
   /* Add objects to the timeline */
   fail_unless (ges_layer_add_clip (layer1, clip1));
@@ -1191,6 +1191,8 @@ GST_START_TEST (test_layer_meta_string)
 
   assert_equals_string (result, "blub");
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1215,6 +1217,8 @@ GST_START_TEST (test_layer_meta_boolean)
 
   fail_unless (result);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1239,6 +1243,8 @@ GST_START_TEST (test_layer_meta_int)
 
   assert_equals_int (result, 1234);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1263,6 +1269,8 @@ GST_START_TEST (test_layer_meta_uint)
 
   assert_equals_int (result, 42);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1287,6 +1295,8 @@ GST_START_TEST (test_layer_meta_int64)
 
   assert_equals_int64 (result, 1234);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1311,6 +1321,8 @@ GST_START_TEST (test_layer_meta_uint64)
 
   assert_equals_uint64 (result, 42);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1336,6 +1348,8 @@ GST_START_TEST (test_layer_meta_float)
 
   assert_equals_float (result, 23.456f);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1363,6 +1377,8 @@ GST_START_TEST (test_layer_meta_double)
   //TODO CHECK
   assert_equals_float (result, 23.456);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1393,6 +1409,8 @@ GST_START_TEST (test_layer_meta_date)
   g_date_free (input);
   g_date_free (result);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1427,6 +1445,8 @@ GST_START_TEST (test_layer_meta_date_time)
   gst_date_time_unref (input);
   gst_date_time_unref (result);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1459,6 +1479,8 @@ GST_START_TEST (test_layer_meta_value)
 
   g_value_unset (&data);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1554,6 +1576,8 @@ GST_START_TEST (test_layer_meta_register)
       "ges-test-value");
   assert_equals_string (result, "Hello world!");
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1586,6 +1610,8 @@ GST_START_TEST (test_layer_meta_foreach)
   ges_meta_container_foreach (GES_META_CONTAINER (layer),
       (GESMetaForeachFunc) test_foreach, NULL);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
@@ -1606,7 +1632,7 @@ GST_START_TEST (test_layer_get_clips_in_interval)
 
   clip = (GESClip *) ges_test_clip_new ();
   fail_unless (clip != NULL);
-  g_object_set (clip, "start", 10, "duration", 30, NULL);
+  g_object_set (clip, "start", (guint64) 10, "duration", (gint64) 30, NULL);
   assert_equals_uint64 (_START (clip), 10);
   assert_equals_uint64 (_DURATION (clip), 30);
 
@@ -1662,7 +1688,7 @@ GST_START_TEST (test_layer_get_clips_in_interval)
   /* Multiple intersecting clips */
   clip2 = (GESClip *) ges_test_clip_new ();
   fail_unless (clip2 != NULL);
-  g_object_set (clip2, "start", 50, "duration", 10, NULL);
+  g_object_set (clip2, "start", (guint64) 50, "duration", (gint64) 10, NULL);
   assert_equals_uint64 (_START (clip2), 50);
   assert_equals_uint64 (_DURATION (clip2), 10);
 
@@ -1670,7 +1696,7 @@ GST_START_TEST (test_layer_get_clips_in_interval)
 
   clip3 = (GESClip *) ges_test_clip_new ();
   fail_unless (clip3 != NULL);
-  g_object_set (clip3, "start", 0, "duration", 5, NULL);
+  g_object_set (clip3, "start", (guint64) 0, "duration", (gint64) 5, NULL);
   assert_equals_uint64 (_START (clip3), 0);
   assert_equals_uint64 (_DURATION (clip3), 5);
 
@@ -1703,6 +1729,8 @@ GST_START_TEST (test_layer_get_clips_in_interval)
   fail_unless (current->data == GES_TIMELINE_ELEMENT (clip2));
   g_list_free_full (objects, gst_object_unref);
 
+  gst_object_unref (timeline);
+
   ges_deinit ();
 }
 
